@@ -1,8 +1,16 @@
 package Crypt::Passphrase::Validator;
-$Crypt::Passphrase::Validator::VERSION = '0.007';
+$Crypt::Passphrase::Validator::VERSION = '0.008';
 use strict;
 use warnings;
 
+sub secure_compare {
+	my ($self, $left, $right) = @_;
+	return if length $left != length $right;
+	my $r = 0;
+	$r |= ord(substr $left, $_, 1) ^ ord(substr $right, $_, 1) for 0 .. length($left) - 1;
+	return $r == 0 ? 1 : undef;
+}
+
 1;
 
 #ABSTRACT: Base class for Crypt::Passphrase validators
@@ -19,7 +27,7 @@ Crypt::Passphrase::Validator - Base class for Crypt::Passphrase validators
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 DESCRIPTION
 
@@ -35,6 +43,10 @@ This method returns true if this validator is able to process a hash. Typically
 
 This checks if a C<$password> satisfies C<$hash>.
 
+=head2 secure_compare($left, $right)
+
+This compares two strings in a way that resists timing attacks.
+
 =head1 AUTHOR
 
 Leon Timmermans <leont@cpan.org>
